@@ -7,7 +7,7 @@
  *	remain fixed across releases, and they may not work, or may
  *	provide different semantics at some point in the future.
  *
- * Copyright (c) 2012-2019 Red Hat.
+ * Copyright (c) 2012-2020 Red Hat.
  * Copyright (c) 2008-2009 Aconex.  All Rights Reserved.
  * Copyright (c) 1995-2002 Silicon Graphics, Inc.  All Rights Reserved.
  *
@@ -494,6 +494,7 @@ typedef enum {
     PM_HASH_WALK_DELETE_STOP,
 } __pmHashWalkState;
 PCP_CALL extern void __pmHashInit(__pmHashCtl *);
+PCP_CALL extern int __pmHashPreAlloc(int, __pmHashCtl *);
 typedef __pmHashWalkState(*__pmHashWalkCallback)(const __pmHashNode *, void *);
 PCP_CALL extern void __pmHashWalkCB(__pmHashWalkCallback, void *, const __pmHashCtl *);
 PCP_CALL extern __pmHashNode *__pmHashWalk(__pmHashCtl *, __pmHashWalkState);
@@ -502,6 +503,7 @@ PCP_CALL extern int __pmHashAdd(unsigned int, void *, __pmHashCtl *);
 PCP_CALL extern int __pmHashDel(unsigned int, void *, __pmHashCtl *);
 PCP_CALL extern void __pmHashClear(__pmHashCtl *);
 
+
 /*
  * Host specification allowing one or more pmproxy host, and port numbers
  * within the one string, i.e. pmcd host specifications of the form:
@@ -846,6 +848,13 @@ PCP_CALL extern int __pmLogPutText(__pmArchCtl *, unsigned int , unsigned int, c
 PCP_CALL extern int __pmLogWriteLabel(__pmFILE *, const __pmLogLabel *);
 PCP_CALL extern int __pmLogLoadLabel(__pmArchCtl *, const char *);
 PCP_CALL extern int __pmLogLoadMeta(__pmArchCtl *);
+PCP_CALL extern int __pmLogAddDesc(__pmArchCtl *, const pmDesc *);
+PCP_CALL extern int __pmLogAddInDom(__pmArchCtl *, const pmTimespec *, const pmInResult *, int *, int);
+PCP_CALL extern int __pmLogAddPMNSNode(__pmArchCtl *, pmID, const char *);
+PCP_CALL extern int __pmLogAddLabelSets(__pmArchCtl *, const pmTimespec *, unsigned int, unsigned int, int, pmLabelSet *);
+PCP_CALL extern int __pmLogAddText(__pmArchCtl *, unsigned int, unsigned int, const char *);
+PCP_CALL extern int __pmLogAddVolume(__pmArchCtl *, unsigned int);
+
 #define PMLOGREAD_NEXT		0
 #define PMLOGREAD_TO_EOF	1
 PCP_CALL extern int __pmLogRead(__pmArchCtl *, int, __pmFILE *, pmResult **, int);
@@ -862,7 +871,9 @@ PCP_CALL extern int __pmLogLookupText(__pmArchCtl *, unsigned int , unsigned int
 PCP_CALL extern int __pmLogNameInDom(__pmArchCtl *, pmInDom, pmTimeval *, int, char **);
 PCP_CALL extern const char *__pmLogLocalSocketDefault(int, char *buf, size_t bufSize);
 PCP_CALL extern const char *__pmLogLocalSocketUser(int, char *buf, size_t bufSize);
+PCP_CALL extern int __pmLogCompressedSuffix(const char *);
 PCP_CALL extern char *__pmLogBaseName(char *);
+PCP_CALL extern char *__pmLogBaseNameVol(char *, int *);
 PCP_DATA extern int __pmLogReads;
 
 /* Convert opaque context handle to __pmContext pointer */
@@ -1229,6 +1240,10 @@ PCP_CALL extern void __pmServerCloseRequestPorts(void);
 PCP_CALL extern void __pmServerDumpRequestPorts(FILE *);
 PCP_CALL extern char *__pmServerRequestPortString(int, char *, size_t);
 
+/* service manager notifications */
+PCP_CALL extern int __pmServerNotifyServiceManagerReady(pid_t);
+PCP_CALL extern int __pmServerNotifyServiceManagerStopping(pid_t);
+
 /* Service broadcasting, for servers. */
 typedef struct __pmServerPresence __pmServerPresence;
 PCP_CALL extern __pmServerPresence *__pmServerAdvertisePresence(const char *, int);
@@ -1283,6 +1298,7 @@ PCP_CALL extern void __pmFreeInResult(pmInResult *);
 PCP_CALL extern void __pmFreePMNS(__pmnsTree *);
 PCP_CALL extern void __pmFreeProfile(pmProfile *);
 PCP_CALL extern void __pmFreeResultValues(pmResult *);
+PCP_CALL extern void __pmFreeDerived(__pmContext *);
 
 /* diagnostics for formatting or printing miscellaneous data structures */
 PCP_CALL extern void __pmDumpContext(FILE *, int, pmInDom);
